### sim_sensors

This is an educational python package that holds classes intended to simulate sensors. The sensors are those you would find in a typical IoT lab or home project.
The objects created can be placed in seperate threads and spun up to spit out values. You can use the created values to demonstrate data visualisation and analysis skills. Or store them in a database and practice sql operations.
Please check the code for additional comments that describe how the various components work.
